<?php
/**
 * Display links to active BuddyPress specific plugins/extensions settings' pages
 *
 * @package    BuddyPress Toolbar
 * @subpackage Plugin/Extension Support
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright 2012, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link       http://genesisthemes.de/en/wp-plugins/buddypress-toolbar/
 * @link       http://twitter.com/#!/deckerweb
 *
 * @since 1.0
 */

/**
 * BuddyPress ScholarPress Courseware (free, by ScholarPress Dev Crew)
 *
 * @since 1.0
 */
if ( ( function_exists( 'is_plugin_active' ) && is_plugin_active( 'buddypress-courseware/courseware.php' ) ) || class_exists( 'BPSP_Courses' ) ) {
	$menu_items['ext-bpcourseware'] = array(
		'parent' => $extensions,
		'title'  => __( 'BuddyPress ScholarPress Courseware', 'buddypress-toolbar' ),
		'href'   => admin_url( 'admin.php?page=bp-courseware' ),
		'meta'   => array( 'target' => '', 'title' => __( 'BuddyPress ScholarPress Courseware', 'buddypress-toolbar' ) )
	);
}  // end-if BP Courseware


/**
 * BP Group Organizer (free, by David Dean)
 *
 * @since 1.0
 */
if ( ( function_exists( 'is_plugin_active' ) && is_plugin_active( 'bp-group-organizer/index.php' ) ) || function_exists( 'bp_group_organizer_admin' ) ) {
	$menu_items['ext-bpgrouporganizer'] = array(
		'parent' => $extensions,
		'title'  => __( 'BP Group Organizer', 'buddypress-toolbar' ),
		'href'   => admin_url( 'admin.php?page=group_organizer' ),
		'meta'   => array( 'target' => '', 'title' => __( 'BP Group Organizer', 'buddypress-toolbar' ) )
	);
}  // end-if BP Group Organizer


/**
 * BP Group Hierarchy (free, by David Dean)
 *
 * @since 1.0
 */
if ( ( function_exists( 'is_plugin_active' ) && is_plugin_active( 'bp-group-hierarchy/index.php' ) ) || class_exists( 'BP_Groups_Hierarchy' ) ) {
	$menu_items['ext-bpgrouphierarchy'] = array(
		'parent' => $extensions,
		'title'  => __( 'BP Group Hierarchy', 'buddypress-toolbar' ),
		'href'   => admin_url( 'admin.php?page=bp_group_hierarchy_settings' ),
		'meta'   => array( 'target' => '', 'title' => __( 'BP Group Hierarchy', 'buddypress-toolbar' ) )
	);
}  // end-if BP Group Hierarchy


/**
 * WangGuard (free, by WangGuard Team)
 *
 * @since 1.4
 */
if ( ( function_exists( 'is_plugin_active' ) && is_plugin_active( 'wangguard/wangguard-admin.php' ) ) || function_exists( 'wangguard_init' ) ) {

	// Entries at "Users" level submenu
	$menu_items['userswangguard'] = array(
		'parent' => $users,
		'title'  => __( 'WangGuard Moderation Queue', 'buddypress-toolbar' ),
		'href'   => admin_url( 'admin.php?page=wangguard_queue' ),
		'meta'   => array( 'target' => '', 'title' => __( 'WangGuard Moderation Queue', 'buddypress-toolbar' ) )
	);
	$menu_items['userswangguard-wizard'] = array(
		'parent' => $users,
		'title'  => __( 'WangGuard Wizard', 'buddypress-toolbar' ),
		'href'   => admin_url( 'admin.php?page=wangguard_wizard' ),
		'meta'   => array( 'title' => __( 'WangGuard Wizard', 'buddypress-toolbar' ) )
	);
	$menu_items['userswangguard-stats'] = array(
		'parent' => $users,
		'title'  => __( 'WangGuard Statistics', 'buddypress-toolbar' ),
		'href'   => admin_url( 'admin.php?page=wangguard_stats' ),
		'meta'   => array( 'title' => __( 'WangGuard Statistics', 'buddypress-toolbar' ) )
	);

	// Entries at "Extensions" level submenu
	$menu_items['extwangguard'] = array(
		'parent' => $extensions,
		'title'  => __( 'WangGuard Moderation Queue', 'buddypress-toolbar' ),
		'href'   => admin_url( 'admin.php?page=wangguard_queue' ),
		'meta'   => array( 'target' => '', 'title' => __( 'WangGuard Moderation Queue', 'buddypress-toolbar' ) )
	);
	$menu_items['extwangguard-wizard'] = array(
		'parent' => $extwangguard,
		'title'  => __( 'Wizard', 'buddypress-toolbar' ),
		'href'   => admin_url( 'admin.php?page=wangguard_wizard' ),
		'meta'   => array( 'title' => __( 'Wizard', 'buddypress-toolbar' ) )
	);
	$menu_items['extwangguard-stats'] = array(
		'parent' => $extwangguard,
		'title'  => __( 'Statistics', 'buddypress-toolbar' ),
		'href'   => admin_url( 'admin.php?page=wangguard_stats' ),
		'meta'   => array( 'title' => __( 'Statistics', 'buddypress-toolbar' ) )
	);
	$menu_items['extwangguard-config'] = array(
		'parent' => $extwangguard,
		'title'  => __( 'Configuration', 'buddypress-toolbar' ),
		'href'   => admin_url( 'admin.php?page=wangguard_conf' ),
		'meta'   => array( 'title' => __( 'Configuration', 'buddypress-toolbar' ) )
	);
}  // end-if WangGuard


/**
 * Members (free, by Justin Tadlock)
 *
 * @since 1.4
 */
if ( ( function_exists( 'is_plugin_active' ) && is_plugin_active( 'members/members.php' ) ) && current_user_can( 'edit_roles' ) ) {

	// Entries at "Users" level submenu
	$menu_items['u-members'] = array(
		'parent' => $users,
		'title'  => __( 'Members: Adjust Roles &amp; Capabilities', 'buddypress-toolbar' ),
		'href'   => admin_url( 'users.php?page=roles' ),
		'meta'   => array( 'target' => '', 'title' => __( 'Members: Adjust Roles &amp; Capabilities', 'buddypress-toolbar' ) )
	);
	$menu_items['u-members-add'] = array(
		'parent' => $users,
		'title'  => __( 'Members: Add new Role', 'buddypress-toolbar' ),
		'href'   => admin_url( 'users.php?page=role-new' ),
		'meta'   => array( 'title' => __( 'Members: Add new Role', 'buddypress-toolbar' ) )
	);
}  // end-if Members
